@@ -1,9 +1,11 @@
 #include "config.h"
 
 #ifndef HAVE_STRSEP
-char* strsep (char**, char*);
+char *strsep (char **, char *);
 #endif
 #ifndef HAVE_POW
 double pow (double, double);
 #endif
-
+#ifndef HAVE_BZERO
+void bzero (void *, size_t);
+#endif
