@@ -49,12 +49,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #ifdef HAVE_LONG_LONG
 #define   HASHTYPE unsigned long long
-#define   COUNTTYPE long long
+#define   COUNTTYPE unsigned long long
 #define   COUNTFORMAT "%*lld"
 #define   COUNTFRACTFORMAT "%0*lld"
 #else /* no long longs */
-#define   HASHTYPE long int
-#define   COUNTTYPE long int
+#define   HASHTYPE unsigned long int
+#define   COUNTTYPE unsigned long int
 #define   COUNTFORMAT "%*ld"
 #define   COUNTFRACTFORMAT "%0*ld"
 #endif /* no long longs */
