@@ -74,6 +74,9 @@ int gi_reference_file_count;
 /* The string to be placed between fields in the output file(s) */
 STRINGTYPE *gs_output_field_delimiter;
 
+/* There is no string to be placed between fields in the output file(s) */
+int gi_no_output_field_delimiter;
+
 /* The string to be placed between records in the output file(s) */
 STRINGTYPE *gs_output_record_delimiter;
 
@@ -86,7 +89,11 @@ STRINGTYPE *gs_data_missing_string;
 /* The string to replace data fields of zero length */
 STRINGTYPE *gs_data_empty_string;
 
-/* The string that separates two fields from each other in the data file */
+/* There is no string that separates two fields from each other in the data file */
+int gi_data_no_input_field_delimiter;
+
+/* The string that separates two fields from each other in the data file can 
+   repeat without creating multiple empty fields*/
 int gi_data_input_field_delimiter_repeat;
 
 /* The string that separates two fields from each other in the data file */
