@@ -101,6 +101,7 @@ struct s_ref_file_info
   STRINGTYPE *missing_string;
   STRINGTYPE *empty_string;
   STRINGTYPE *input_field_delimiter;
+  int no_input_field_delimiter;
   int input_field_delimiter_repeat;
   STRINGTYPE *input_record_delimiter;
   int input_record_length;
@@ -146,11 +147,13 @@ extern unsigned char *gs_data_output_buffer;
 extern size_t gi_data_output_buffer_size;
 extern size_t gi_data_output_buffer_pos;
 extern STRINGTYPE *gs_output_field_delimiter;
+extern int gi_no_output_field_delimiter;
 extern STRINGTYPE *gs_output_record_delimiter;
 extern STRINGTYPE *gs_data_constant_string;
 extern STRINGTYPE *gs_data_missing_string;
 extern STRINGTYPE *gs_data_empty_string;
 extern STRINGTYPE *gs_data_input_field_delimiter;
+extern int gi_data_no_input_field_delimiter;
 extern int gi_data_input_field_delimiter_repeat;
 extern STRINGTYPE *gs_data_input_record_delimiter;
 extern field_id *gra_data_output_field_order;
