@@ -82,6 +82,8 @@ enum
 #define OPT_NO_STATISTICS 302
 #define CUT_OPT_OUTPUT_DELIMITER 303
 #define OPT_INPUT_DELIMITER_REPEAT 304
+#define OPT_NO_INPUT_DELIMITER 305
+#define OPT_NO_OUTPUT_DELIMITER 306
 
 #define COMMON_SHORT_OPTIONS "+a:b:B:d:D:e:fF:h:H:k:K:lL:m:Mno:O:pPr:Rs:t:uUvwx:X:z:"
 
@@ -90,7 +92,10 @@ static struct option const long_options[] = {
   {"output-record-delimiter", required_argument, NULL, 'b'},
   {"input-record-delimiter", required_argument, NULL, 'B'},
   {"output-field-delimiter", required_argument, NULL, 'd'},
+  {"no-output-field-delimiter", required_argument, NULL,
+   OPT_NO_OUTPUT_DELIMITER},
   {"input-field-delimiter", required_argument, NULL, 'D'},
+  {"no-input-field-delimiter", required_argument, NULL, OPT_NO_INPUT_DELIMITER},
   {"input-field-delimiter-repeat", no_argument, NULL,
    OPT_INPUT_DELIMITER_REPEAT},
   {"emulate", required_argument, NULL, 'e'},
@@ -183,6 +188,7 @@ initialize_variables (argc, argv)
   gi_statistics_ind = 1;
   gi_checkallref_ind = 1;
   gi_hashmovement_ind = hm_binary_long;	/* Assume that most keys will react well to having the low order 4 bits from every byte used in the hash key. */
+  gi_no_output_field_delimiter = 0;
   gi_data_write_ind = 0;
   gi_data_suppress_empty_ind = 0;
   gi_data_optional_ind = 0;
@@ -562,12 +568,27 @@ validate_options ()
   int j;
 
 
+  /* If we specified a data input field delimiter, pass it to any reference
+   * files that neither have a delimiter specified nor have the "no delimiter"
+   * option set.
+   */
+  if (gs_data_input_field_delimiter != NULL) {
+    for (i = 0; i < gi_reference_file_count; i++) {
+      if (gra_reference_file_info[i].input_field_delimiter == NULL
+	  && gra_reference_file_info[i].no_input_field_delimiter == 0)
+	gra_reference_file_info[i].input_field_delimiter
+	  = gs_data_input_field_delimiter;
+      }
+    if (gs_output_field_delimiter == NULL && gi_no_output_field_delimiter == 0)
+      gs_output_field_delimiter = gs_data_input_field_delimiter;
+    }
+
   /* Work through all the field ranges in any delimited-field input
      files and expand the ranges to a single field per range. */
-  if (gs_data_input_field_delimiter != NULL)
+  if (gs_data_input_field_delimiter != NULL) {
     expand_delimited_ranges (&gra_data_out_ranges, &gi_data_out_range_count);
-  if (gs_data_input_field_delimiter != NULL)
     expand_delimited_ranges (&gra_data_sum_ranges, &gi_data_sum_range_count);
+    }
 
   for (j = 0; j < gi_reference_file_count; j++) {
     if (gs_data_input_field_delimiter != NULL)
@@ -1081,6 +1102,7 @@ set_file_option (option)
       gs_data_input_field_delimiter = dstrdupstr (optarg);
       if (gs_data_input_field_delimiter == NULL)
 	FATAL_ERROR (_("unable to allocate memory"));
+      gi_data_no_input_field_delimiter = 0;
       }
     else {
       gra_reference_file_info[gi_reference_file_count - 1].input_field_delimiter
@@ -1088,6 +1110,29 @@ set_file_option (option)
       if (gra_reference_file_info[gi_reference_file_count - 1]
 	  .input_field_delimiter == NULL)
 	FATAL_ERROR (_("unable to allocate memory"));
+      gra_reference_file_info[gi_reference_file_count
+			      - 1].no_input_field_delimiter = 0;
+      }
+    break;
+  case OPT_NO_INPUT_DELIMITER:
+    if (gi_reference_file_count == 0) {
+      /* Data file info. */
+      gi_data_no_input_field_delimiter = -1;
+      if (gs_data_input_field_delimiter != NULL) {
+	dstrfree (gs_data_input_field_delimiter);
+	gs_data_input_field_delimiter = NULL;
+	}
+      }
+    else {
+      gra_reference_file_info[gi_reference_file_count
+			      - 1].no_input_field_delimiter = -1;
+      if (gra_reference_file_info[gi_reference_file_count - 1]
+	  .input_field_delimiter != NULL) {
+	dstrfree (gra_reference_file_info[gi_reference_file_count - 1]
+		  .input_field_delimiter);
+	gra_reference_file_info[gi_reference_file_count
+				- 1].input_field_delimiter = NULL;
+	}
       }
     break;
   case OPT_INPUT_DELIMITER_REPEAT:
@@ -1246,6 +1291,8 @@ set_reference_file (filename)
   gra_reference_file_info[gi_reference_file_count - 1].empty_string = NULL;
   gra_reference_file_info[gi_reference_file_count - 1].input_field_delimiter
     = NULL;
+  gra_reference_file_info[gi_reference_file_count - 1].no_input_field_delimiter
+    = 0;
   gra_reference_file_info[gi_reference_file_count
 			  - 1].input_field_delimiter_repeat = 0;
   gra_reference_file_info[gi_reference_file_count - 1].input_record_delimiter
@@ -1308,6 +1355,14 @@ set_general_option (option)
     gs_output_field_delimiter = dstrdupstr (optarg);
     if (gs_output_field_delimiter == NULL)
       FATAL_ERROR (_("unable to allocate memory"));
+    gi_no_output_field_delimiter = 0;
+    break;
+  case OPT_NO_OUTPUT_DELIMITER:
+    gi_no_output_field_delimiter = -1;
+    if (gs_output_field_delimiter != NULL) {
+      dstrfree (gs_output_field_delimiter);
+      gs_output_field_delimiter = NULL;
+      }
     break;
   case 'f':
     gi_flag_ind = 1;
@@ -1652,6 +1707,7 @@ handle_join_arguments (argc, argv)
   set_reference_file ("temp_reference_file");
   gi_data_write_ind = 1;
   gs_data_input_field_delimiter = dstrdupstr (" ");
+  gi_data_no_input_field_delimiter = 0;
   if (gs_data_input_field_delimiter == NULL)
     FATAL_ERROR (_("unable to allocate memory"));
   gra_reference_file_info[0].input_field_delimiter = dstrdupstr (" ");
