@@ -833,8 +833,16 @@ dstrmakeown (string)
 
     memmove (new_string, string->string, string->length);
     string->string = new_string;
-    string->own_string = DStr_own;
     }
+  else if (string->string != NULL) {
+    /* Assume a 1-byte null string */
+    new_string = malloc (1);
+    if (new_string == NULL)
+      return NULL;
+    new_string[0] = '\0';
+    string->string = new_string;
+    }
+  string->own_string = DStr_own;
 
   return string;
   }
