@@ -92,6 +92,13 @@ create_scheme_string_variable (name, number, value)
     }
   return_val = scm_mem2string (value->string, value->length);
   return_val = scm_c_define (var_name, return_val);
+  /* I thight this was helpful, but I guess we give the name away to guile.
+   * pending confirmation that this is the case, I'll try commenting it out
+   * again.  Given that it will fall under the garbage collection there, we
+   * ought not be concerned if it appears to be a leak at times.
+   * MAINTAIN
+   free (var_name);
+   */
 #  else
   command = malloc (50 + name->length + value->length);
   strcpy (command, "(define ");
@@ -197,9 +204,10 @@ eval_scheme_command (command)
   if (command_0str == NULL)
     FATAL_ERROR (_("unable to allocate memory"));
   strncpy (command_0str, command->string, command->length);
-  command_0str[command->length = '\0';
-	       return_val = gh_eval_str (command_0str); free (command_0str);
+  command_0str[command->length] = '\0';
+  return_val = gh_eval_str (command_0str);
+  free (command_0str);
 #    endif /* HAVE_LIBGUILE_H */
-	       return return_val;
-	       }
+  return return_val;
+  }
 #  endif /* HAVE_LIBGUILE */
