@@ -135,6 +135,7 @@ process_reference_files ()
 	input_record_desc->string = result_string->string;
 	input_record_desc->length = result_string->length;
 	input_record_desc->own_string = DStr_not_own;
+        result_string->own_string = DStr_not_own;
 	dstrfree (result_string);
 	free (command_string);
 	}
@@ -396,6 +397,7 @@ process_data_file (input_filename)
       input_record_desc->string = result_string->string;
       input_record_desc->length = result_string->length;
       input_record_desc->own_string = DStr_not_own;
+      result_string->own_string = DStr_not_own;
       dstrfree (result_string);
       free (command_string);
       }
@@ -461,10 +463,6 @@ process_data_file (input_filename)
       gi_data_records_dropped_filter++;
       }
 
-    if (value != NULL)
-      dstrfree (value);
-    value = NULL;
-
     for (i = 0; i < gi_data_out_range_count; i++)
       dstrfree (output_fields[i]);
     free (output_fields);
@@ -644,8 +642,10 @@ process_data_reference_matches (data_output_fields, reference_file_number,
 	REFINFO[reference_file_number].current_hash_selection = hash_index;
       else if (gi_reference_file_count != 0)
 	REFINFO[reference_file_number].current_hash_selection = -1;
-      if (*write_record == 0 && gi_checkallref_ind == 0)
+      if (*write_record == 0 && gi_checkallref_ind == 0) {
+	dstrfree (key_value);
 	return EXIT_SUCCESS;
+	}
       if (reference_file_number < gi_reference_file_count - 1) {
 	process_data_reference_matches (data_output_fields,
 					reference_file_number + 1, write_record,
@@ -675,7 +675,9 @@ process_data_reference_matches (data_output_fields, reference_file_number,
       hash_index = REFINFO[reference_file_number].hash_size + 1;
   } while (gi_reference_file_count > 0
 	     && hash_index != REFINFO[reference_file_number].hash_size + 1);
-
+/*
+  dstrfree (key_value);
+ */
   return EXIT_SUCCESS;
   }
 
@@ -1248,6 +1250,7 @@ traverse_hierarchy (data_output_fields, reference_file_number, write_record,
 	else {			/* We're at the end of the line, so write the record */
 	  if (*write_record != 0 && gi_data_write_ind == 1) {
 	    int return_code;
+	    REFINFO[reference_file_number].current_hash_selection = hash_entry;
 	    write_match_record (data_output_fields);
 	    }
 	  }
