@@ -1,5 +1,5 @@
 /* combine - flexible file merging    
-   Copyright (C) 2002, 2003 Daniel P. Valentine
+   Copyright (C) 2002, 2003 Free Software Foundation, Inc.
 
    This file was written by Daniel P. Valentine <dpv@world.std.com>
 
@@ -17,10 +17,11 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-int hrchy_add_path (HASHTYPE, HASHTYPE, HASHTYPE**, HASHTYPE*, STRINGTYPE*);
-int process_reference_files();
-int process_data_file(char*);
-int process_data_reference_matches (STRINGTYPE**, int, int*, STRINGTYPE*);
-HASHTYPE traverse_hierarchy (STRINGTYPE**, int, int*, STRINGTYPE*, HASHTYPE, HASHTYPE);
-int update_counters (int, HASHTYPE, STRINGTYPE**, STRINGTYPE*);
-int write_output();
+int hrchy_add_path (HASHTYPE, HASHTYPE, HASHTYPE **, HASHTYPE *, STRINGTYPE *);
+int process_reference_files ();
+int process_data_file (char *);
+int process_data_reference_matches (STRINGTYPE **, int, int *, STRINGTYPE *);
+HASHTYPE traverse_hierarchy (STRINGTYPE **, int, int *, STRINGTYPE *, HASHTYPE,
+			     HASHTYPE);
+int update_counters (int, HASHTYPE, STRINGTYPE **, STRINGTYPE *);
+int write_output ();
