@@ -1,5 +1,5 @@
 /* combine - flexible file merging    
-   Copyright (C) 2002, 2003, 2004 Daniel P. Valentine
+   Copyright (C) 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This file was written by Daniel P. Valentine <dpv@world.std.com>
 
@@ -21,6 +21,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #include <stdio.h>
 #include "df_common.h"
 
-int df_write_output (FILE*, unsigned char**, size_t*, size_t*, STRINGTYPE*, STRINGTYPE*, int, int);
+int df_write_output (FILE *, unsigned char **, size_t *, size_t *, STRINGTYPE *,
+		     STRINGTYPE *, int, int);
 
-int df_write_field (FILE*, unsigned char**, size_t*, size_t*, STRINGTYPE*, STRINGTYPE*, int*, int, int);
+int df_write_field (FILE *, unsigned char **, size_t *, size_t *, STRINGTYPE *,
+		    STRINGTYPE *, int *, int, int);
